"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HwpAttributesPlugin = void 0;
const html_webpack_plugin_1 = __importDefault(require("html-webpack-plugin"));
const minimatch_1 = require("minimatch");
const PLUGIN = 'HwpAttributesPlugin';
class HwpAttributesPlugin {
    constructor(options = {}) {
        this._options = {
            module: options.module || [],
            nomodule: options.nomodule || [],
            async: options.async || [],
            defer: options.defer || [],
        };
    }
    apply(compiler) {
        compiler.hooks.compilation.tap(PLUGIN, (compilation) => {
            const hooks = html_webpack_plugin_1.default.getHooks(compilation);
            hooks.alterAssetTags.tapAsync(PLUGIN, (data, cb) => {
                data.assetTags.scripts = this._transformAssets(data.assetTags.scripts);
                return cb(null, data);
            });
        });
    }
    _transformAssets(assets) {
        return assets.map((asset) => {
            if (asset.tagName === 'script' && asset.attributes.src) {
                const module = this._options.module.some((pattern) => (0, minimatch_1.minimatch)(`${asset.attributes.src}`, pattern));
                const nomodule = !module &&
                    this._options.nomodule.some((pattern) => (0, minimatch_1.minimatch)(`${asset.attributes.src}`, pattern));
                const async = this._options.async.some((pattern) => (0, minimatch_1.minimatch)(`${asset.attributes.src}`, pattern));
                const defer = this._options.defer.some((pattern) => (0, minimatch_1.minimatch)(`${asset.attributes.src}`, pattern));
                if (module) {
                    asset.attributes.type = 'module';
                }
                else if (nomodule) {
                    asset.attributes.nomodule = true;
                }
                if (async) {
                    asset.attributes.async = true;
                }
                if (defer) {
                    asset.attributes.defer = true;
                }
            }
            return asset;
        });
    }
}
exports.HwpAttributesPlugin = HwpAttributesPlugin;
//# sourceMappingURL=index.js.map